# Views Access Conditions

This module provides a Views access plugin that allows you to control access to
views based on configurable conditions using Drupal's Conditions API.

## Features

- Adds a new "Conditions" access plugin to Views
- Allows configuration of multiple conditions that must be met for access
- Integrates with Drupal's Conditions API
- Supports all standard Drupal conditions (user roles, node types, etc.)
- Allows other modules to alter available conditions through hooks
- Provides an administration interface to control which conditions are available

## Usage

1. Edit a View
2. Under "Access" settings, select "Conditions" as the access type
3. Configure the desired conditions in the form that appears
4. Save the View

## Administration

The module provides an administration interface at
`/admin/config/system/views-access-conditions` where site administrators with
the "Administer Views Access Conditions settings" permission can control which
conditions are available for use.

By default, all conditions are available. If specific conditions are enabled
through the admin interface, only those conditions will be available when
configuring Views access.

## Requirements

- Drupal 10 or 11
- Views module
- Conditions API (part of Drupal core)

## Installation

1. Place the module in your `modules/contrib` directory
2. Enable the module through Drupal's admin interface or using Drush:
   ```bash
   drush en views_access_conditions
   ```

## Permissions

- **Administer Views Access Conditions settings**: Controls access to the
  configuration form that determines which conditions are available.

## API

The module provides the following hook for other modules to alter the available
conditions:

```php
/**
 * Alter the conditions available for views access.
 *
 * @param array $conditions
 *   The array of conditions to alter.
 * @param \Drupal\Core\Form\FormStateInterface $form_state
 *   The form state object.
 * @param string $form_id
 *   (Optional) The form_id of the form being altered.
 */
hook_views_access_conditions_available_conditions_alter(array &$conditions,
FormStateInterface $form_state, ?string $form_id);
```

## License

This project is licensed under the GNU General Public License v2.0.
